imageObject Classes — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »

# imageObject Classes

This class and related sub-classes manage all the instrument-specific images for processing by AstroDrizzle.

- Base ImageObject Classes
- ACS ImageObjects
- WFC3 ImageObjects
- STIS ImageObjects
- NICMOS ImageObjects
- WFPC2 ImageObjects

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »